# If you use this work, please cite:

[Akhter et al](https://academic.oup.com/nar/article/40/16/e126/1027055/PhiSpy-a-novel-algorithm-for-finding-prophages-in)

Sajia Akhter, Ramy K. Aziz, Robert A. Edwards; PhiSpy: a novel algorithm for finding prophages in bacterial genomes that combines similarity- and composition-based strategies. Nucl Acids Res 2012; 40 (16): e126. doi: 10.1093/nar/gks406

For the newest versions, please also cite:

McNair, K., Decewicz, P., Akhter, S., Aziz, R.K., Daniel, S., Edwards, R.A. 2019. PhiSpy. https://github.com/linsalrob/PhiSpy/ doi://10.5281/zenodo.3475717
